| Title: | Privacy-Preserving Distributed Algorithms |
|---|---|
| Description: | A collection of privacy-preserving distributed algorithms (PDAs) for conducting federated statistical learning across multiple data sites. The PDA framework includes models for various tasks such as regression, trial emulation, causal inference, design-specific analysis, and clustering. The PDA algorithms run on a lead site and only require summary statistics from collaborating sites, with one or few iterations. The package can be used together with the online data transfer system (<https://pda-ota.pdamethods.org/>) for safe and convenient collaboration. For more information, please visit our software websites: <https://github.com/Penncil/pda>, and <https://pdamethods.org/>. |
| Authors: | Chongliang Luo [cre], Rui Duan [aut], Mackenzie Edmondson [aut], Jiayi Tong [aut], Xiaokang Liu [aut], Kenneth Locke [aut], Jie Hu [aut], Bingyu Zhang [aut], Yicheng Shen [aut], Yudong Wang [aut], Yiwen Lu [aut], Lu Li [aut], Yong Chen [aut], Penn Computing Inference Learning (PennCIL) lab [cph] |
| Maintainer: | Chongliang Luo <[email protected]> |
| License: | Apache License 2.0 |
| Version: | 1.3.0 |
| Built: | 2026-05-17 06:56:42 UTC |
| Source: | https://github.com/cran/pda |
A simulated data set for ADAP demonstration
ADAP_dataADAP_data
A list containing the following elements:
site id, 300 'site1', 300 'site2', 300 'site3'
binary outcome of length 900
900 by 49 matrix generated by standard normal distribution, representing the covariates
A simulated COVID-19 data set for Collaborative One-shot and Lossless Algorithms of generalized linear models (COLA-GLM)
COLA_covidCOLA_covid
A data frame with 1500 rows and 6 variables:
site, 600 'site1', 500 'site2', 400 'site3'
binary age
binary sex
binary medical condition
binary outcome, COVID-19 status. This is the binary outcome for COLA logistic regression
poisson outcome, number of visits. This is the count outcome for COLA Poisson regression
A simulated data set of hospitalization Length of Stay (LOS) and mortality from 6 sites
covidcovid
A data frame with 2100 rows and 6 variables:
site id, 600 'site1', 500 'site2', 400 'site3', 300 'site4', 200 'site5', 100 'site6'
continuous age in year, min 3 max 97
2 categories, '1' for male and '0' for female
lab test results, continuous value ranging from 2.3 to 97.4
LOS in days, ranging from 1 to 29
mortality status, '1' for death and '0' for alive.
A data set modified from the CrabSatellites data in countreg package (see demo(ODAH)).
cscs
A data frame containing 173 observations on 4 variables.
Simulated site id, 85 'site1' and 88 'site2'.
Number of satellites. Treated as (zero-inflated) count outcome in ODAH
Carapace width (cm).
Weight (kg).
https://rdrr.io/rforge/countreg/man/CrabSatellites.html
gather cloud settings into a list
getCloudConfig(site_id,dir=NULL,uri=NULL,secret=NULL,silent_message=T)getCloudConfig(site_id,dir=NULL,uri=NULL,secret=NULL,silent_message=T)
site_id |
site identifier |
dir |
shared directory path if flat files |
uri |
web uri if web service |
secret |
web token if web service |
silent_message |
logical, if the message will be muted |
A list of cloud parameters: site_id, secret and uri
pda
A simulated ADRD data set for Lossless Oneshot Algorithm for Target Trial Emulation (LATTE)
LATTE_ADRDLATTE_ADRD
A data frame with 1224 rows and 326 variables:
Unique patient identifier
History of Stroke or Transient Ischemic Attack, binary indicator
History of Acquired Hypothyroidism, binary indicator
History of Fibromyalgia, Chronic Pain and Fatigue, binary indicator
History of RA/OA (Rheumatoid Arthritis / Osteoarthritis), binary indicator
History of Hypertension, binary indicator
History of Anxiety Disorders, binary indicator
History of Chronic Obstructive Pulmonary Disease (COPD) and Bronchiectasis, binary indicator
History of Asthma, binary indicator
History of Traumatic Brain Injury and Nonpsychotic Mental Disorders due to Brain Damage, binary indicator
History of Sleep disorders, binary indicator
History of ADHD, Conduct Disorders, and Hyperkinetic Syndrome, binary indicator
History of Cataract, binary indicator
History of Migraine and Chronic Headache, binary indicator
History of Depressive Disorders, binary indicator
History of Hyperlipidemia, binary indicator
History of Sensory Deafness and Hearing Impairment, binary indicator
History of Female/Male Breast Cancer, binary indicator
History of Personality Disorders, binary indicator
History of Anemia, binary indicator
History of Chronic Kidney Disease, binary indicator
History of Schizophrenia and Other Psychotic Disorders, binary indicator
History of Glaucoma, binary indicator
History of Peripheral Vascular Disease (PVD), binary indicator
History of Heart Failure, binary indicator
History of Pressure and Chronic Ulcers, binary indicator
History of Obesity, binary indicator
History of Diabetes, binary indicator
History of Mobility Impairments, binary indicator
History of Benign Prostatic Hyperplasia, binary indicator
History of Drug Use Disorders, binary indicator
History of Alcohol Use Disorders, binary indicator
History of Post Traumatic Stress Disorder (PTSD), binary indicator
History of Atrial Fibrillation, binary indicator
History of Tobacco Use, binary indicator
History of Ischemic Heart Disease, binary indicator
History of Liver Disease (Cirrhosis and Other Liver Conditions except Viral Hepatitis), binary indicator
History of Sensory Blindness and Visual Impairment, binary indicator
History of Bipolar Disorder, binary indicator
History of Depression, binary indicator
History of Prostate Cancer, binary indicator
History of Acute Myocardial Infarction, binary indicator
History of Hip/Pelvic Fracture, binary indicator
History of Other Developmental Delays, binary indicator
History of Viral Hepatitis (General), binary indicator
History of Sickle Cell Disease, binary indicator
History of Multiple Sclerosis and Transverse Myelitis, binary indicator
History of Leukemias and Lymphomas, binary indicator
History of Opioid Use Disorder, binary indicator
History of Colorectal Cancer, binary indicator
History of Epilepsy, binary indicator
History of Osteoporosis, binary indicator
History of Intellectual Disabilities and Related Conditions, binary indicator
History of Spinal Cord Injury, binary indicator
History of Endometrial Cancer, binary indicator
History of Spina Bifida and Other Congenital Anomalies of the Nervous System, binary indicator
History of Learning Disabilities, binary indicator
History of Periodontitis, binary indicator
History of Lung Cancer, binary indicator
History of Cystic Fibrosis and Other Metabolic Developmental Disorders, binary indicator
History of Cerebral Palsy, binary indicator
History of Human Immunodeficiency Virus and/or Acquired Immunodeficiency Syndrome (HIV/AIDS), binary indicator
History of Menopause, binary indicator
History of Muscular Dystrophy, binary indicator
History of Autism Spectrum Disorders, binary indicator
History of atorvastatin use, binary indicator
History of hydrochlorothiazide use, binary indicator
History of amlodipine use, binary indicator
History of aspirin use, binary indicator
History of metoprolol use, binary indicator
History of levothyroxine use, binary indicator
History of metformin use, binary indicator
History of lisinopril use, binary indicator
History of simvastatin use, binary indicator
History of sodium chloride use, binary indicator
History of omeprazole use, binary indicator
History of albuterol use, binary indicator
History of potassium chloride use, binary indicator
History of sertraline use, binary indicator
History of lidocaine use, binary indicator
History of furosemide use, binary indicator
History of losartan use, binary indicator
History of donepezil use, binary indicator
History of cholecalciferol use, binary indicator
History of ondansetron use, binary indicator
History of oxycodone use, binary indicator
History of lorazepam use, binary indicator
History of glucose oxidase use, binary indicator
History of prednisone use, binary indicator
History of fluticasone use, binary indicator
History of gabapentin use, binary indicator
History of rosuvastatin use, binary indicator
History of tamsulosin use, binary indicator
History of fentanyl use, binary indicator
History of carbidopa use, binary indicator
History of pantoprazole use, binary indicator
History of escitalopram use, binary indicator
History of insulin aspart (human) use, binary indicator
History of clonazepam use, binary indicator
History of carvedilol use, binary indicator
History of heparin use, binary indicator
History of bupropion use, binary indicator
History of polyethylene glycol 3350 use, binary indicator
History of pravastatin use, binary indicator
History of docusate use, binary indicator
History of vitamin B12 use, binary indicator
History of clopidogrel use, binary indicator
History of atenolol use, binary indicator
History of glipizide use, binary indicator
History of ascorbic acid use, binary indicator
History of glucose use, binary indicator
History of insulin glargine use, binary indicator
History of zolpidem use, binary indicator
History of warfarin use, binary indicator
History of azithromycin use, binary indicator
History of trazodone use, binary indicator
History of esomeprazole use, binary indicator
History of sennosides (USP) use, binary indicator
History of propofol use, binary indicator
History of iopamidol use, binary indicator
History of diltiazem use, binary indicator
History of ibuprofen use, binary indicator
History of dexamethasone use, binary indicator
History of tramadol use, binary indicator
History of amoxicillin use, binary indicator
History of midazolam use, binary indicator
History of lansoprazole use, binary indicator
History of citalopram use, binary indicator
History of valsartan use, binary indicator
History of ciprofloxacin use, binary indicator
History of famotidine use, binary indicator
History of calcium carbonate use, binary indicator
History of finasteride use, binary indicator
History of levofloxacin use, binary indicator
History of sulfamethoxazole use, binary indicator
History of duloxetine use, binary indicator
History of alprazolam use, binary indicator
History of naproxen use, binary indicator
History of levetiracetam use, binary indicator
History of ranitidine use, binary indicator
History of triamcinolone use, binary indicator
History of salmeterol use, binary indicator
History of folic acid use, binary indicator
History of nifedipine use, binary indicator
History of ferrous sulfate use, binary indicator
History of morphine use, binary indicator
History of hydralazine use, binary indicator
History of montelukast use, binary indicator
History of magnesium sulfate use, binary indicator
History of methylphenidate use, binary indicator
History of hydrocortisone use, binary indicator
History of latanoprost use, binary indicator
History of quetiapine use, binary indicator
History of metronidazole use, binary indicator
History of diphenhydramine use, binary indicator
History of memantine use, binary indicator
History of methylprednisolone use, binary indicator
History of doxycycline use, binary indicator
History of fluoxetine use, binary indicator
History of paroxetine use, binary indicator
History of gadobenate use, binary indicator
History of propranolol use, binary indicator
History of ramipril use, binary indicator
History of ezetimibe use, binary indicator
History of allopurinol use, binary indicator
History of enoxaparin use, binary indicator
Binary indicator for history of apixaban
Binary indicator for history of sildenafil
Binary indicator for history of oxybutynin
Binary indicator for history of insulin lispro
Binary indicator for history of melatonin
Binary indicator for history of tadalafil
Binary indicator for history of hydromorphone
Binary indicator for history of ipratropium
Binary indicator for history of cephalexin
Binary indicator for history of lovastatin
Binary indicator for history of mirtazapine
Binary indicator for history of venlafaxine
Binary indicator for history of fenofibrate
Binary indicator for history of guaifenesin
Binary indicator for history of estradiol
Binary indicator for history of nitroglycerin
Binary indicator for history of pregabalin
Binary indicator for history of lamotrigine
Binary indicator for history of enalapril
Binary indicator for history of ergocalciferol
Binary indicator for history of ketoconazole
Binary indicator for history of spironolactone
Binary indicator for history of cyclobenzaprine
Binary indicator for history of meloxicam
Binary indicator for history of cetirizine
Binary indicator for history of alendronate
Binary indicator for history of nortriptyline
Binary indicator for history of bisacodyl
Binary indicator for history of sitagliptin
Binary indicator for history of salmon oil
Binary indicator for history of olmesartan
Binary indicator for history of timolol
Binary indicator for history of nitrofurantoin
Binary indicator for history of celecoxib
Binary indicator for history of glimepiride
Binary indicator for history of iohexol
Binary indicator for history of clonidine
Binary indicator for history of valacyclovir
Binary indicator for history of ropinirole
Binary indicator for history of bupivacaine
Binary indicator for history of benzonatate
Binary indicator for history of carbamazepine
Binary indicator for history of meclizine
Binary indicator for history of azelastine
Binary indicator for history of diclofenac
Binary indicator for history of clobetasol
Binary indicator for history of ketorolac
Binary indicator for history of amphetamine
Binary indicator for history of budesonide
Binary indicator for history of diazepam
Binary indicator for history of repaglinide
Binary indicator for history of omega-3-acid ethyl esters (USP)
Binary indicator for history of methadone
Binary indicator for history of clindamycin
Binary indicator for history of rivaroxaban
Binary indicator for history of vitamin E
Binary indicator for history of valproate
Binary indicator for history of tiotropium
Binary indicator for history of temazepam
Binary indicator for history of chlorhexidine
Binary indicator for history of hydroxychloroquine
Binary indicator for history of nystatin
Binary indicator for history of olanzapine
Binary indicator for history of nicotine
Binary indicator for history of mometasone
Binary indicator for history of prednisolone
Binary indicator for history of conjugated estrogens (USP)
Binary indicator for history of mupirocin
Binary indicator for history of loratadine
Binary indicator for history of fexofenadine
Binary indicator for history of solifenacin
Binary indicator for history of irbesartan
Binary indicator for history of ephedrine
Binary indicator for history of isosorbide
Binary indicator for history of gadoterate meglumine
Binary indicator for history of ubidecarenone
Binary indicator for history of verapamil
Binary indicator for history of promethazine
Binary indicator for history of doxazosin
Binary indicator for history of fluconazole
Binary indicator for history of haloperidol
Binary indicator for history of rivastigmine
Binary indicator for history of labetalol
Binary indicator for history of eszopiclone
Binary indicator for history of insulin detemir
Binary indicator for history of aripiprazole
Binary indicator for history of vancomycin
Binary indicator for history of thiamine
Binary indicator for history of epinephrine
Binary indicator for history of amitriptyline
Binary indicator for history of tolterodine
Binary indicator for history of cefazolin
Binary indicator for history of lisdexamfetamine
Binary indicator for history of risperidone
Binary indicator for history of mirabegron
Binary indicator for history of magnesium oxide
Binary indicator for history of niacin
Binary indicator for history of pramipexole
Binary indicator for history of zoledronic acid
Binary sex
Age (continuous)
Race
Time from index to event (continuous)
Index date of diagnosis
Binary treatment indicator
Outcome binary indicator: AD
Outcome time: AD
Outcome binary indicator: ADRD
Outcome time: ADRD
Outcome binary indicator: acute conjunctivitis
Outcome time: acute conjunctivitis
Outcome binary indicator: acute tonsillitis
Outcome time: acute tonsillitis
Outcome binary indicator: adhesive capsulitis of shoulder
Outcome time: adhesive capsulitis of shoulder
Outcome binary indicator: allergic rhinitis
Outcome time: allergic rhinitis
Outcome binary indicator: blepharitis
Outcome time: blepharitis
Outcome binary indicator: carpal tunnel syndrome
Outcome time: carpal tunnel syndrome
Outcome binary indicator: chalazion
Outcome time: chalazion
Outcome binary indicator: contact dermatitis
Outcome time: contact dermatitis
Outcome binary indicator: dental caries
Outcome time: dental caries
Outcome binary indicator: deviated nasal septum
Outcome time: deviated nasal septum
Outcome binary indicator: foreign body in ear
Outcome time: foreign body in ear
Outcome binary indicator: gout
Outcome time: gout
Outcome binary indicator: hemorrhoids
Outcome time: hemorrhoids
Outcome binary indicator: impacted cerumen
Outcome time: impacted cerumen
Outcome binary indicator: influenza
Outcome time: influenza
Outcome binary indicator: ingrowing nail
Outcome time: ingrowing nail
Outcome binary indicator: low back pain
Outcome time: low back pain
Outcome binary indicator: menieres disease
Outcome time: menieres disease
Outcome binary indicator: osteoarthritis of knee
Outcome time: osteoarthritis of knee
Outcome binary indicator: osteoporosis
Outcome time: osteoporosis
Outcome binary indicator: foot drop
Outcome time: foot drop
Outcome binary indicator: hearing problem
Outcome time: hearing problem
Outcome binary indicator: intra abdominal and pelvic swelling mass and lump
Outcome time: intra abdominal and pelvic swelling mass and lump
Outcome binary indicator: irritability and anger
Outcome time: irritability and anger
Outcome binary indicator: wristdrop
Outcome time: wristdrop
Study site identifier
A simulated long-covid data set for Distributed causal inference with covariates shift (DisC2o). This only contains 5 covariates and more noisy covariates can be added when running demo example.
long_covidlong_covid
A data frame with 900 rows and 53 variables:
number of Post Acute Sequelae of COVID (PASC, or long covid) features
treatment of covid vaccination, 1=vaccinated
site id, 300 participants each for 'site1', 'site2', and 'site3'
a binary covariate
a binary covariate
a continuous covariate
a continuous covariate
a continuous covariate
A simulated data set of hospitalization Length of Stay (LOS) from 3 sites
LOSLOS
A data frame with 1000 rows and 5 variables:
site id, 500 'site1', 400 'site2' and 100 'site3'
3 categories, 'young', 'middle', and 'old'
2 categories, 'M' for male and 'F' for female
lab test results, continuous value ranging from 0 to 100
LOS in days, ranging from 1 tp 28. Treated as continuous outcome in DLM
A data set modified from the lung data in survival package (see demo(ODAC)).
lung2lung2
A data frame with 228 rows and 5 variables:
simulated site id, 86 'site1', 83 'site2' and 59 'site3'
survival time in days
censoring status 0=censored, 1=dead
age in years
1 for female and 0 for male
https://CRAN.R-project.org/package=survival
A simulated data set for ODACATH demonstration
nominal_data_heteronominal_data_hetero
A list containing the following elements:
site id, 100 'site1', 100 'site2', 100 'site3'
nominal outcome taking values 1,2,3
a continuous covariate
a binary covariate
A simulated data set for ODACAT demonstration
ODACAT_nominalODACAT_nominal
A list containing the following elements:
site id, 100 'site1', 100 'site2', 100 'site3'
nominal outcome taking values 1,2,3
a continuous covariate
a binary covariate
a binary covariate
A simulated data set for ODACAT demonstration
ODACAT_ordinalODACAT_ordinal
A data frame with 300 rows and 5 variables:
site id, 105 'site1', 105 'site2', 90 'site3'
3-category outcome, possible values are 1,2,3. Category 3 will be used as reference
the first covariate, continuous
the second covariate, binary
the third covariate, binary
A simulated data set for ODACH with case-cohort design demonstration
odach_ccodach_cc
A data frame with 413 rows and 8 variables:
site id, 187 'site1', 133 'site2', 93 'site3'. The full_cohort_size are 800, 600 and 400 respectively
1=subcohort, e.g. uniformly subsampled from full_cohort_size, 0=case
survival time
censoring status 0=censored, 1=dead
the first covariate, continuous
the second covariate, continuous
the third covariate, categorical
the fourth covariate, categorical
A simulated data set for ODACATH demonstration
ordinal_dataordinal_data
A list containing the following elements:
site id, 100 'site1', 100 'site2', 100 'site3'
ordinal outcome taking values 1,2,3
a continuous covariate
a binary covariate
Fit Privacy-preserving Distributed Algorithms for linear, logistic, Poisson and Cox PH regression with possible heterogeneous data across sites.
pda(ipdata=NULL,site_id,control=NULL,dir=NULL,uri=NULL,secret=NULL, upload_without_confirm=F, silent_message=F, digits=4,hosdata=NULL)pda(ipdata=NULL,site_id,control=NULL,dir=NULL,uri=NULL,secret=NULL, upload_without_confirm=F, silent_message=F, digits=4,hosdata=NULL)
ipdata |
Local IPD data in data frame, should include at least one column for the outcome and one column for the covariates |
site_id |
Character site name |
control |
pda control data |
dir |
directory for shared flat file cloud |
uri |
Universal Resource Identifier for this run |
secret |
password to authenticate as site_id on uri |
upload_without_confirm |
logical. TRUE if want silent upload, no interactive confirm |
silent_message |
logical. TRUE if want to mute message |
digits |
digits after decimal points in the output json files |
hosdata |
(for dGEM) hospital-level data, should include the same name as defined in the control file |
control
control
Michael I. Jordan, Jason D. Lee & Yun Yang (2019) Communication-Efficient Distributed Statistical Inference,
Journal of the American Statistical Association, 114:526, 668-681
doi:10.1080/01621459.2018.1429274.
(DLM) Yixin Chen, et al. (2006) Regression cubes with lossless compression and aggregation.
IEEE Transactions on Knowledge and Data Engineering, 18(12), pp.1585-1599.
(DLMM) Chongliang Luo, et al. (2020) Lossless Distributed Linear Mixed Model with Application to Integration of Heterogeneous Healthcare Data.
medRxiv, doi:10.1101/2020.11.16.20230730.
(DPQL) Chongliang Luo, et al. (2021) dPQL: a lossless distributed algorithm for generalized linear mixed model with application to privacy-preserving hospital profiling.
medRxiv, doi:10.1101/2021.05.03.21256561.
(ODAL) Rui Duan, et al. (2020) Learning from electronic health records across multiple sites:
A communication-efficient and privacy-preserving distributed algorithm.
Journal of the American Medical Informatics Association, 27.3:376–385,
doi:10.1093/jamia/ocz199.
(ODAC) Rui Duan, et al. (2020) Learning from local to global: An efficient distributed algorithm for modeling time-to-event data.
Journal of the American Medical Informatics Association, 27.7:1028–1036,
doi:10.1093/jamia/ocaa044.
(ODACH) Chongliang Luo, et al. (2021) ODACH: A One-shot Distributed Algorithm for Cox model with Heterogeneous Multi-center Data.
medRxiv, doi:10.1101/2021.04.18.21255694.
(ODAH) Mackenzie J. Edmondson, et al. (2021) An Efficient and Accurate Distributed Learning Algorithm for Modeling Multi-Site Zero-Inflated Count Outcomes.
medRxiv, pp.2020-12.
doi:10.1101/2020.12.17.20248194.
(ADAP) Xiaokang Liu, et al. (2021) ADAP: multisite learning with high-dimensional heterogeneous data via A Distributed Algorithm for Penalized regression.
(dGEM) Jiayi Tong, et al. (2022) dGEM: Decentralized Generalized Linear Mixed Effects Model
(COLA) Wu, Q., Reps, J.M., Li, L. et al. COLA-GLM: collaborative one-shot and lossless algorithms of generalized linear models for decentralized observational healthcare data. npj Digit. Med. 8, 442 (2025). https://doi.org/10.1038/s41746-025-01781-1.
(ODACT) Liang CJ, Luo C, Kranzler HR, Bian J, Chen Y. Communication-efficient federated learning of temporal effects on opioid use disorder with data from distributed research networks. J Am Med Inform Assoc. 2025 Apr 1;32(4):656-664. doi: 10.1093/jamia/ocae313. PMID: 39864407; PMCID: PMC12005629.
(DisC2o) Tong J, et al. 2025. DisC2o-HD: Distributed causal inference with covariates shift for analyzing real-world high-dimensional data. Journal of Machine Learning Research. 2025;26(3):1-50.
pdaPut, pdaList, pdaGet, getCloudConfig and pdaSync.
use this function to guide end-users step-by-step to identify best pda models for their tasks, and set up control.
pdaCatalog(task=c('Regression', 'Survival', 'Trial_emulation', 'Causal_inference', 'Design_analysis', 'Clustering'), write_json_file_path=getwd(), optim_maxit,optim_method,init_method)pdaCatalog(task=c('Regression', 'Survival', 'Trial_emulation', 'Causal_inference', 'Design_analysis', 'Clustering'), write_json_file_path=getwd(), optim_maxit,optim_method,init_method)
task |
user-specified task, c('Regression', 'Survival', 'Trial_emulation', 'Causal_inference', 'Design_analysis', 'Clustering'). If no specify, display all models |
write_json_file_path |
directory path to write the control file to |
optim_maxit |
option in the control file for the optimization in pda, default 100 |
optim_method |
option in the control file for the optimization in pda, default "BFGS" |
init_method |
option in the control file for calculating the initial estimate in pda, default "meta" |
pda control
pda
Function to download json and return as object
pdaGet(name,config)pdaGet(name,config)
name |
of file |
config |
cloud configuration |
A list of data objects from the json file on the cloud
pda
Function to list available objects
pdaList(config)pdaList(config)
config |
a list of variables for cloud configuration |
A list of (json) files on the cloud
pda
Function to upload object to cloud as json
pdaPut(obj,name,config,upload_without_confirm=F,silent_message=F,digits=4)pdaPut(obj,name,config,upload_without_confirm=F,silent_message=F,digits=4)
obj |
R object to encode as json and uploaded to cloud |
name |
of file |
config |
a list of variables for cloud configuration |
upload_without_confirm |
logical. TRUE if want silent upload, no interactive confirm |
silent_message |
logical. TRUE if want to mute message |
digits |
digits after decimal points in the output json files |
NONE
pda
update pda control if ready (run by lead)
pdaSync(config,upload_without_confirm,silent_message, digits)pdaSync(config,upload_without_confirm,silent_message, digits)
config |
cloud configuration |
upload_without_confirm |
logical. TRUE if want silent upload, no interactive confirm |
silent_message |
logical. TRUE if want to mute message |
digits |
digits after decimal points in the output json files |
control
pda
Function to perform all data processing and pooled stratified analysis
run_pooled_analysis(data, outcome_id, outcome_time, sites)run_pooled_analysis(data, outcome_id, outcome_time, sites)
data |
The combined LATTE_ADRD data. |
outcome_id |
The name of the primary outcome column. |
outcome_time |
The name of the outcome time column (for Poisson). |
sites |
A vector of site identifiers. |
A list containing the results of the standard logistic and Poisson pooled analysis.